fn image_loading_error_from_cairo(
status: Error,
aurl: &AllowedUrl,
) -> LoadingErrorExpand description
Converts a cairo::Error that happened while wrapping a decoded raster image
into a LoadingError augmented with the image’s URL.
fn image_loading_error_from_cairo(
status: Error,
aurl: &AllowedUrl,
) -> LoadingErrorConverts a cairo::Error that happened while wrapping a decoded raster image
into a LoadingError augmented with the image’s URL.