load_image_resource_from_bytes

Function load_image_resource_from_bytes 

fn load_image_resource_from_bytes(
    load_options: &LoadOptions,
    aurl: &AllowedUrl,
    bytes: Vec<u8>,
    format: ImageFormat,
) -> Result<Resource, LoadingError>
Decodes BinaryData that is presumed to be a raster image.

To know which decoder to use (or to even decide if this is a supported image format), this function uses the mime_type field in the BinaryData.

The AllowedUrl is not used for decoding; it is just to construct an error message for the return value.