struct Resources {
resources: HashMap<AllowedUrl, Result<Resource, LoadingError>>,
}Expand description
Set of external resources (other SVG documents, or raster images) referenced by an SVG.
For example, a PNG image in <image href="foo.png"/> gets decoded
and stored here, referenced by its URL.
Fields
resources: HashMap<AllowedUrl, Result<Resource, LoadingError>>Implementations
Sourceimpl Resources
impl Resources
fn new() -> Resources
Sourcefn lookup_node(
&mut self,
session: &Session,
load_options: &LoadOptions,
url: &str,
id: &str,
cancellable: Option<&Cancellable>,
) -> Result<Node<NodeData>, LoadingError>
fn lookup_node( &mut self, session: &Session, load_options: &LoadOptions, url: &str, id: &str, cancellable: Option<&Cancellable>, ) -> Result<Node<NodeData>, LoadingError>
Looks up a specific node by its id in another SVG document.
For example, in <use href="foo.svg#some_node"/>, or in filter="url(filters.svg#foo)".
The URL is not validated yet; this function will take care of that and return a suitable error.
Sourcefn get_extern_document(
&mut self,
session: &Session,
load_options: &LoadOptions,
href: &str,
cancellable: Option<&Cancellable>,
) -> Result<Resource, LoadingError>
fn get_extern_document( &mut self, session: &Session, load_options: &LoadOptions, href: &str, cancellable: Option<&Cancellable>, ) -> Result<Resource, LoadingError>
Validates the URL and loads an SVG document as a Resource.
The document can then be used whole (<image href="foo.svg"/>, or individual
elements from it can be looked up (<use href="foo.svg#some_node"/>).
Sourcefn lookup_resource(
&mut self,
session: &Session,
load_options: &LoadOptions,
aurl: &AllowedUrl,
cancellable: Option<&Cancellable>,
) -> Result<Resource, LoadingError>
fn lookup_resource( &mut self, session: &Session, load_options: &LoadOptions, aurl: &AllowedUrl, cancellable: Option<&Cancellable>, ) -> Result<Resource, LoadingError>
Loads a resource (an SVG document or a raster image), or returns an already-loaded one.